@@ -1708,13 +1708,16 @@ class Model:
     ) -> List[str]:
         """Find reactions out of a reference model necessary to produce
         all given targets from a given seed"""
-        return topological.gapfilling(
-            model=self,
-            reference_model=reference_model,
-            seed=seed,
-            targets=targets,
-            include_weak_cofactors=include_weak_cofactors,
-            verbose=verbose,
+        if verbose:
+            warnings.warn("Verbose keyword is deprecated since 1.10.0", category=DeprecationWarning)
+        return sorted(
+            topological.gapfilling(
+                model=self,
+                db=reference_model,
+                seed=seed,
+                targets=targets,
+                include_weak_cofactors=include_weak_cofactors,
+            )
         )
 
     def gapfilling(
